@@ -7,6 +7,7 @@ our @ISA = qw(Log::Log4perl::Appender);
 use warnings;
 use strict;
 use Log::Log4perl::Config::Watch;
+use Fcntl;
 use constant _INTERNAL_DEBUG => 0;
 
 ##################################################
@@ -17,17 +18,25 @@ sub new {
     my $self = {
         name      => "unknown name",
         umask     => undef,
+        owner     => undef,
+        group     => undef,
         autoflush => 1,
+        syswrite  => 0,
         mode      => "append",
         binmode   => undef,
         utf8      => undef,
         recreate  => 0,
         recreate_check_interval => 30,
-        recreate_signal         => undef,
+        recreate_check_signal   => undef,
         recreate_pid_write      => undef,
         @options,
     };
 
+    if(defined $self->{umask} and $self->{umask} =~ /^0/) {
+            # umask value is a string, meant to be an oct value
+        $self->{umask} = oct($self->{umask});
+    }
+
     die "Mandatory parameter 'filename' missing" unless
         exists $self->{filename};
 
@@ -61,22 +70,46 @@ sub file_open {
 ##################################################
     my($self) = @_;
 
-    my $arrows = ">";
+    my $arrows  = ">";
+    my $sysmode = (O_CREAT|O_WRONLY);
 
     my $old_umask = umask();
 
     if($self->{mode} eq "append") {
-        $arrows = ">>";
+        $arrows   = ">>";
+        $sysmode |= O_APPEND;
     } elsif ($self->{mode} eq "pipe") {
         $arrows = "|";
+    } else {
+        $sysmode |= O_TRUNC;
     }
 
     my $fh = do { local *FH; *FH; };
 
     umask($self->{umask}) if defined $self->{umask};
 
-    open $fh, "$arrows$self->{filename}" or
-        die "Can't open $self->{filename} ($!)";
+    my $didnt_exist = ! -f $self->{filename};
+
+    if($self->{syswrite}) {
+        sysopen $fh, "$self->{filename}", $sysmode or
+            die "Can't sysopen $self->{filename} ($!)";
+    } else {
+        open $fh, "$arrows$self->{filename}" or
+            die "Can't open $self->{filename} ($!)";
+    }
+
+    if($didnt_exist and 
+         ( defined $self->{owner} or defined $self->{group} )
+      ) {
+
+        eval { $self->perms_fix() };
+
+        if($@) {
+              # Cleanup and re-throw
+            unlink $self->{filename};
+            die $@;
+        }
+    }
 
     if($self->{recreate}) {
         $self->{watcher} = Log::Log4perl::Config::Watch->new(
@@ -92,7 +125,7 @@ sub file_open {
 
     $self->{fh} = $fh;
 
-    if ($self->{autoflush}) {
+    if ($self->{autoflush} and ! $self->{syswrite}) {
         my $oldfh = select $self->{fh}; 
         $| = 1; 
         select $oldfh;
@@ -115,6 +148,43 @@ sub file_close {
     undef $self->{fh};
 }
 
+##################################################
+sub perms_fix {
+##################################################
+    my($self) = @_;
+
+    my ($uid_org, $gid_org) = (stat $self->{filename})[4,5];
+
+    my ($uid, $gid) = ($uid_org, $gid_org);
+
+    if(!defined $uid) {
+        die "stat of $self->{filename} failed ($!)";
+    }
+
+    my $needs_fixing = 0;
+
+    if(defined $self->{owner}) {
+        $uid = $self->{owner};
+        if($self->{owner} !~ /^\d+$/) {
+            $uid = (getpwnam($self->{owner}))[2];
+            die "Unknown user: $self->{owner}" unless defined $uid;
+        }
+    }
+
+    if(defined $self->{group}) {
+        $gid = $self->{group};
+        if($self->{group} !~ /^\d+$/) {
+            $gid = getgrnam($self->{group});
+
+            die "Unknown group: $self->{group}" unless defined $gid;
+        }
+    }
+    if($uid != $uid_org or $gid != $gid_org) {
+        chown($uid, $gid, $self->{filename}) or 
+            die "chown('$uid', '$gid') on '$self->{filename}' failed: $!";
+    }
+}
+
 ##################################################
 sub file_switch {
 ##################################################
@@ -148,8 +218,13 @@ sub log {
 
     my $fh = $self->{fh};
 
-    print $fh $params{message} or
-        die "Cannot write to '$self->{filename}': $!";
+    if($self->{syswrite}) {
+        syswrite $fh, $params{message} or
+            die "Cannot syswrite to '$self->{filename}': $!";
+    } else {
+        print $fh $params{message} or
+            die "Cannot write to '$self->{filename}': $!";
+    }
 }
 
 ##################################################
@@ -218,6 +293,15 @@ as executable to pipe output to. Default mode is C<"append">.
 C<autoflush>, if set to a true value, triggers flushing the data
 out to the file on every call to C<log()>. C<autoflush> is on by default.
 
+=item syswrite
+
+C<syswrite>, if set to a true value, makes sure that the appender uses
+syswrite() instead of print() to log the message. C<syswrite()> usually
+maps to the operating system's C<write()> function and makes sure that
+no other process writes to the same log file while C<write()> is busy.
+Might safe you from having to use other syncronisation measures like
+semaphores (see: Synchronized appender).
+
 =item umask
 
 Specifies the C<umask> to use when creating the file, determining
@@ -226,6 +310,20 @@ If set to C<0222> (default), new
 files will be created with C<rw-r--r--> permissions.
 If set to C<0000>, new files will be created with C<rw-rw-rw-> permissions.
 
+=item owner
+
+If set, specifies that the owner of the newly created log file should
+be different from the effective user id of the running process.
+Only makes sense if the process is running as root. 
+Both numerical user ids and user names are acceptable.
+
+=item group
+
+If set, specifies that the group of the newly created log file should
+be different from the effective group id of the running process.
+Only makes sense if the process is running as root.
+Both numerical group ids and group names are acceptable.
+
 =item utf8
 
 If you're printing out Unicode strings, the output filehandle needs
@@ -280,7 +378,7 @@ has been moved or deleted. If this is undesirable,
 setting C<recreate_check_interval> to 0 will have the appender
 appender check the file with I<every> call to C<log()>.
 
-=item recreate_signal
+=item recreate_check_signal
 
 In C<recreate> mode, if this option is set to a signal name
 (e.g. "USR1"), the appender will recreate a missing logfile
